@@ -5,7 +5,7 @@ use strict;
 use utf8;
 use Carp;
 
-our $VERSION = 'v2.0.0';
+our $VERSION = 'v2.0.1';
 
 use Scalar::Util qw( weaken );
 use EV;
@@ -62,7 +62,7 @@ Cache::Sliding - Cache using sliding time-based expiration strategy
 
 =head1 VERSION
 
-This document describes Cache::Sliding version v2.0.0
+This document describes Cache::Sliding version v2.0.1
 
 
 =head1 SYNOPSIS
@@ -88,18 +88,22 @@ because cache expiration will work only while you inside EV::loop.
 
 =head1 INTERFACE 
 
-=over
+=head2 new
 
-=item new( $expire_after )
+    $cache = Cache::Sliding->new( $expire_after );
 
 Create and return new cache object. Elements in this cache will expire
 between $expire_after seconds and 2*$expire_after seconds.
 
-=item set( $key, $value )
+=head2 set
+
+    $cache->set( $key, $value );
 
 Add new item into cache. Will replace existing item for that $key, if any.
 
-=item get( $key )
+=head2 get
+
+    $value = $cache->get( $key );
 
 Return value of cached item for $key. If there no cached item for that $key
 return nothing.
@@ -113,12 +117,12 @@ able to check is item was found in cache:
  $val = $cache->get( 'nosuch' );  # $val is undef
  @val = $cache->get( 'nosuch' );  # @val is ()
 
-=item del( $key )
+=head2 del
+
+    $cache->del( $key );
 
 Remove item for $key from cache, if any. Return nothing.
 
-=back
-
 
 =head1 SUPPORT
 
@@ -172,7 +176,7 @@ Alex Efros E<lt>powerman@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2009 by Alex Efros E<lt>powerman@cpan.orgE<gt>.
+This software is Copyright (c) 2009- by Alex Efros E<lt>powerman@cpan.orgE<gt>.
 
 This is free software, licensed under:
 
